<?php

namespace Drupal\Tests\marketo_ma_webform\Unit;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\marketo_ma\Service\MarketoMaServiceInterface;
use Drupal\marketo_ma_webform\Plugin\WebformHandler\MarketoMaWebformHandler;
use Drupal\Tests\UnitTestCase;
use Drupal\webform\WebformSubmissionConditionsValidatorInterface;
use Drupal\webform\WebformSubmissionInterface;

/**
 * MarketoMaWebformHandler kernel tests.
 *
 * @group marketo_ma_webform
 */
class MarketoMaWebformHandlerTest extends UnitTestCase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = ['webform', 'marketo_ma', 'marketo_ma_webform'];

  protected function setUp() {
    parent::setUp();

    // Get constructor args and mocks.
    $configuration = [
      'settings' => [
        'marketo_ma_mapping' => [
          'my_form_element_1' => 'email',
          'my_form_element_2' => 'firstName',
          'my_form_element_3' => 'lastName',
        ],
      ],
    ];
    $plugin_id = 'marketo_ma';
    $plugin_definition = '';
    $this->logger_factory = $this->prophesize(LoggerChannelFactoryInterface::class);
    $this->config_factory = $this->prophesize(ConfigFactoryInterface::class);
    $this->entity_type_manager = $this->prophesize(EntityTypeManagerInterface::class);
    $this->conditions_validator = $this->prophesize(WebformSubmissionConditionsValidatorInterface::class);
  }

  public function testGetLeadProf() {
    $webform_submission_array = [
      'my_form_element_1' => 'foo',
      'my_form_element_2' => 'bar',
      'my_form_element_3' => 'baz',
    ];

    $webform_submission = $this->prophesize(WebformSubmissionInterface::class);
    $webform_submission->toArray(TRUE)->willReturn(['data' => $webform_submission_array]);

    $marketo_service = $this->prophesize(MarketoMaServiceInterface::class);
    $marketo_service->getMarketoFields()->willReturn($this->getMarketoFields());

    $sot = new class(
      [
        'settings' => [
          'marketo_ma_mapping' => [
            'my_form_element_1' => 'email',
            'my_form_element_2' => 'firstName',
            'my_form_element_3' => 'lastName',
          ],
        ],
      ],
      'marketo_ma',
      '',
      $this->logger_factory->reveal(),
      $this->config_factory->reveal(),
      $this->entity_type_manager->reveal(),
      $this->conditions_validator->reveal(),
      $marketo_service->reveal()
    ) extends MarketoMaWebformHandler {

      public function getLead(WebformSubmissionInterface $webform_submission) {
        return parent::getlead($webform_submission);
      }

    };
    /** @var \Drupal\marketo_ma\Lead $lead */
    $lead = $sot->getLead($webform_submission->reveal());
    $this->assertEquals([
      'email' => 'foo',
      'firstName' => 'bar',
      'lastName' => 'baz',
    ], $lead->data());
  }

  private function getMarketoFields() {
    return [
      'firstName' => [
        'id' => 41,
        'displayName' => 'First Name',
        'dataType' => 'string',
        'length' => '255',
        'restName' => 'firstName',
        'restReadOnly' => 0,
        'soapName' => 'FirstName',
        'soapReadOnly' => 0,
      ],
      'lastName' => [
        'id' => 43,
        'displayName' => 'Last Name',
        'dataType' => 'string',
        'length' => '255',
        'restName' => 'lastName',
        'restReadOnly' => 0,
        'soapName' => 'LastName',
        'soapReadOnly' => 0,
      ],
      'email' => [
        'id' => 44,
        'displayName' => 'Email Address',
        'dataType' => 'email',
        'length' => '255',
        'restName' => 'email',
        'restReadOnly' => 0,
        'soapName' => 'Email',
        'soapReadOnly' => 0,
      ],
      'Additional_Comments' => [
        'id' => 2565,
        'displayName' => 'Additional Comments:',
        'dataType' => 'text',
        'length' => '',
        'restName' => 'Additional_Comments',
        'restReadOnly' => 0,
        'soapName' => 'Additional_Comments',
        'soapReadOnly' => 0,
      ],
    ];
  }

}
