<?php

namespace Drupal\Tests\marketo_ma\Kernel;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\KernelTests\KernelTestBase;
use Drupal\marketo_ma\Service\MarketoMaApiClient;
use Drupal\marketo_ma\Service\MarketoMaApiClientInterface;
use Drupal\marketo_ma\Service\MarketoMaServiceInterface;
use Drupal\Tests\marketo_ma\Traits\TestFieldsTrait;
use Psr\Log\LoggerInterface;

/**
 * Base for Marketo MA kernel tests.
 *
 * @group marketo_ma
 */
abstract class MarketoMaKernelTestBase extends KernelTestBase {

  use TestFieldsTrait;

  /**
   * The marketo_ma service.
   *
   * @var \Drupal\marketo_ma\Service\MarketoMaServiceInterface
   */
  protected $service;

  /**
   * The marketo_ma rest client service.
   *
   * @var \Drupal\marketo_ma\Service\MarketoMaApiClientInterface
   */
  protected $api_client;

  protected $test_lead_email;

  /**
   * @var \Drupal\Core\Config\Config
   */
  protected $config;

  /**
   * {@inheritdoc}
   */
  public static $modules = [
    'user',
    'encryption',
    'marketo_ma',
  ];

  /**
   * @var \Drupal\marketo_ma\Service\MarketoMaApiClientInterface|\Prophecy\Prophecy\ObjectProphecy
   */
  protected $realClient;

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();

    // Install config for this module.
    $this->installConfig('marketo_ma');
    // Install module schema.
    $this->installSchema('marketo_ma', 'marketo_ma_lead_fields');

    $config_factory = \Drupal::configFactory();
    // Get the API client service.
    $this->realClient = $this->prophesize(MarketoMaApiClientInterface::class);
    $this->api_client = new class ($config_factory, \Drupal::logger('marketo_ma'), $this->realClient->reveal()) extends MarketoMaApiClient {
      public function __construct(
        ConfigFactoryInterface $config_factory,
        LoggerInterface $logger,
        MarketoMaApiClientInterface $apiClient
      ) {
        parent::__construct($config_factory, $logger);
        $this->client = $apiClient;
      }

    };

    $this->createSampleFields();

    //\Drupal::service('marketo_ma.api_client');;
    // Get the marketo_ma service.
    $this->service = \Drupal::service('marketo_ma');

    // Set the test lead ID.
    $this->test_lead_email = 'test_lead-' . $this->randomMachineName() . '@marketo.com';

    $this->config = $config_factory->getEditable(MarketoMaServiceInterface::MARKETO_MA_CONFIG_NAME);
  }

}
