<?php

namespace Drupal\Tests\marketo_ma\Traits;

use Drupal\marketo_ma\Service\MarketoMaMunchkinInterface;
use Drupal\marketo_ma\Service\MarketoMaServiceInterface;

trait MarketoMaFunctionalHelperTrait {

  /**
   * @var \Drupal\Core\Config\Config
   */
  protected $config;

  /**
   * @var string
   */
  protected $accountId;

  /**
   * @var string
   */
  protected $privateKey;

  /**
   * @var string
   */
  protected $restClientId;

  /**
   * @var string
   */
  protected $restClientSecret;

  protected function mockConfig() {
    // Generate a random encryption key.
    $settings['settings']['encryption_key'] = (object) [
      'value' => base64_encode(random_bytes(32)),
      'required' => TRUE,
    ];
    $this->writeSettings($settings);

    // TODO Randomize?
    $this->accountId = 'asdf';
    $this->privateKey = 'asdf';
    $this->restClientId = 'asdf';
    $this->restClientSecret = 'asdf';

    // Set up required settings.
    $this->config = \Drupal::configFactory()->getEditable(MarketoMaServiceInterface::MARKETO_MA_CONFIG_NAME);
    $encryption_service = \Drupal::service('encryption');
    $this->config
      ->set('instance_host', $encryption_service->encrypt('https://example.com/'))
      ->set('munchkin.account_id', $encryption_service->encrypt($this->accountId))
      ->set('munchkin.api_private_key', $encryption_service->encrypt($this->privateKey))
      ->set('rest.client_id', $encryption_service->encrypt($this->restClientId))
      ->set('rest.client_secret', $encryption_service->encrypt($this->restClientSecret))
      ->save();
  }

  /**
   * Gets drupal settings and parses into an php array.
   *
   * @return array
   *   The drupal settings object.
   */
  protected function getDrupalSettings() {
    // Get the active drupal settings from the session.
    return $this->getSession()->evaluateScript('function(){ if (typeof drupalSettings !== \'undefined\') { return drupalSettings; }}()');
  }

  protected function assertMunchkinTracking($tracking = TRUE, $actions = NULL) {
    $drupal_settings = $this->getDrupalSettings();
    $url = $this->getSession()->getCurrentUrl();
    $this->assertTrue(!empty($drupal_settings['marketo_ma']), 'Marketo settings included: ' . $url);
    $marketo_ma_settings = $drupal_settings['marketo_ma'];
    $this->assertEquals($this->accountId, $marketo_ma_settings['key'], 'Munchkin code included: ' . $url);
    $this->assertEquals($tracking, $marketo_ma_settings['track'], 'Correct marketo track flag status: ' . $url);
    if (isset($actions)) {
      $this->assertFalse(empty($marketo_ma_settings['actions']), 'Actions: ' . $url);
      foreach ($actions as $k => $v) {
        $this->assertTrue(!empty($marketo_ma_settings['actions'][0]['hash']), 'Action hash exists');
        // These are a bit dynamic and harder to assert.
        unset($marketo_ma_settings['actions'][$k]['hash']);
        unset($marketo_ma_settings['actions'][$k]['data']['cookies']);
      }
      $this->assertEquals($actions, $marketo_ma_settings['actions']);
    }
    else {
      $this->assertTrue(empty($marketo_ma_settings['actions']), 'No actions: ' . $url);
    }
  }

  protected function assertNoMunchkinTracking() {
    $drupal_settings = $this->getDrupalSettings();
    $url = $this->getSession()->getCurrentUrl();
    $this->assertTrue(empty($drupal_settings['marketo_ma']), 'No tracking on page: ' . $url);
  }

}
