<?php

namespace Drupal\Tests\marketo_ma\Unit;

use Drupal\marketo_ma\MarketoFieldDefinition;
use Drupal\marketo_ma\Service\MarketoMaServiceInterface;
use Drupal\Tests\UnitTestCase;

/**
 * @coversDefaultClass \Drupal\marketo_ma\MarketoFieldDefinition
 *
 * @group marketo_ma
 */
class MarketoFieldDefinitionUnitTest extends UnitTestCase {

  protected $field_data;

  protected function setUp() {
    parent::setUp();

    $this->field_data = [
      'id' => 1,
      'displayName' => 'First Name',
      'dataType' => "string",
      'rest' => [
        'name' => 'firstName',
        'readOnly' => FALSE,
      ],
      'soap' => [
        'name' => 'firstname',
        'readOnly' => FALSE,
      ],
    ];

  }

  /**
   * @covers ::__construct
   */
  public function testSerialization() {
    $field = new MarketoFieldDefinition($this->field_data);
    $this->assertEquals($field, unserialize(serialize($field)));
  }

  /**
   * @covers ::id
   */
  public function testId() {
    $field = new MarketoFieldDefinition($this->field_data);
    $this->assertEquals($this->field_data['id'], $field->id());
  }

  /**
   * @covers ::getDisplayName
   */
  public function testDisplayName() {
    $field = new MarketoFieldDefinition($this->field_data);
    $this->assertEquals($this->field_data['displayName'], $field->getDisplayName());
  }

  /**
   * @covers ::getFieldName
   */
  public function testFieldName() {
    $field = new MarketoFieldDefinition($this->field_data);

    $this->assertEquals($this->field_data['rest']['name'], $field->getFieldName(MarketoMaServiceInterface::TRACKING_METHOD_API));
    $this->assertEquals($this->field_data['soap']['name'], $field->getFieldName(MarketoMaServiceInterface::TRACKING_METHOD_MUNCHKIN));
  }

}
